package com.nova.flutter_ads;

import android.Manifest;
import android.app.Activity;
import android.support.v4.app.ActivityCompat;
import android.support.v4.content.ContextCompat;
import android.util.Log;
import android.widget.Toast;

import com.ark.adkit.polymers.ttad.config.TTAdManagerHolder;
import com.ark.utils.permissions.PermissionChecker;
import com.bytedance.sdk.openadsdk.AdSlot;
import com.bytedance.sdk.openadsdk.TTAdConstant;
import com.bytedance.sdk.openadsdk.TTAdManager;
import com.bytedance.sdk.openadsdk.TTAdNative;
import com.bytedance.sdk.openadsdk.TTRewardVideoAd;

import io.flutter.app.FlutterActivity;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry.Registrar;

import static android.content.pm.PackageManager.PERMISSION_GRANTED;

/**
 * FlutterAdsPlugin
 */
public class FlutterAdsPlugin implements MethodCallHandler {

    private static Activity activity;
    private TTAdNative mTTAdNative;
    private TTRewardVideoAd mttRewardVideoAd;

    /**
     * Plugin registration.
     */
    public static void registerWith(Registrar registrar) {
        FlutterAdsPlugin flutterAdsPlugin = new FlutterAdsPlugin();
        final MethodChannel channel = new MethodChannel(registrar.messenger(), "flutter_ads");
        channel.setMethodCallHandler(flutterAdsPlugin);

        activity = registrar.activity();

        //注册开屏广告UI插件
        SplashViewFactory factory = new SplashViewFactory((FlutterActivity) registrar.activity(), registrar.messenger());
        registrar.platformViewRegistry().registerViewFactory("plugins.nova.ads/splashview", factory);

        //注册本地广告
        NativeViewFactory nativeViewFactory = new NativeViewFactory((FlutterActivity) registrar.activity(), registrar.messenger());
        registrar.platformViewRegistry().registerViewFactory("plugins.nova.ads/nativeview", nativeViewFactory);

        //注册banner广告
        BannerViewFactory bannerViewFactory = new BannerViewFactory((FlutterActivity) registrar.activity(), registrar.messenger());
        registrar.platformViewRegistry().registerViewFactory("plugins.nova.ads/bannerview", bannerViewFactory);


        //注册Video广告
        VideoViewFactory videoViewFactory = new VideoViewFactory(((FlutterActivity) registrar.activity()), registrar.messenger());
        registrar.platformViewRegistry().registerViewFactory("plugins.nova.ads/videoview", videoViewFactory);

    }

    @Override
    public void onMethodCall(MethodCall call, Result result) {
        if (call.method.equals("getPlatformVersion")) {
            result.success("Android " + android.os.Build.VERSION.RELEASE);
        } else  if(call.method.equals("initRewardVideo")){
            TTAdManager ttAdManager = TTAdManagerHolder.getInstance(activity, "5007439");
            //step2:(可选，强烈建议在合适的时机调用):申请部分权限，如read_phone_state,防止获取不了imei时候，下载类广告没有填充的问题。
            ttAdManager.requestPermissionIfNecessary(activity);
//        //step3:创建TTAdNative对象,用于调用广告请求接口
            mTTAdNative = ttAdManager.createAdNative(activity.getApplicationContext());

            if (ContextCompat.checkSelfPermission(activity, Manifest.permission.ACCESS_FINE_LOCATION) != PERMISSION_GRANTED) {
                ActivityCompat.requestPermissions(activity, new String[]{Manifest.permission.ACCESS_FINE_LOCATION}, 1);
                loadAd("907439399", TTAdConstant.VERTICAL);
            }else {
                loadAd("907439399", TTAdConstant.VERTICAL);
            }

        }else if (call.method.equals("loadRewardVideo")) {
            if (mttRewardVideoAd!=null){
                mttRewardVideoAd.showRewardVideoAd(activity);
            }else {
                result.success("广告未加载成功");
            }
        } else {
            result.notImplemented();
        }
    }

    private void loadAd(String codeId, int orientation) {
        //step4:创建广告请求参数AdSlot,具体参数含义参考文档
        AdSlot adSlot = new AdSlot.Builder()
                .setCodeId(codeId)
                .setSupportDeepLink(true)
                .setImageAcceptedSize(1080, 1920)
                .setRewardName("金币") //奖励的名称
                .setRewardAmount(3)  //奖励的数量
                .setUserID("1992")//用户id,必传参数
                .setMediaExtra("media_extra") //附加参数，可选
                .setOrientation(orientation) //必填参数，期望视频的播放方向：TTAdConstant.HORIZONTAL 或 TTAdConstant.VERTICAL
                .build();
        //step5:请求广告
        mTTAdNative.loadRewardVideoAd(adSlot, new TTAdNative.RewardVideoAdListener() {
            @Override
            public void onError(int code, String message) {
                String message1 = message;

                int code1 = code;
            }

            //视频广告加载后，视频资源缓存到本地的回调，在此回调后，播放本地视频，流畅不阻塞。
            @Override
            public void onRewardVideoCached() {
                Log.d("onRewardVideoCached","onRewardVideoCached");
            }

            //视频广告的素材加载完毕，比如视频url等，在此回调后，可以播放在线视频，网络不好可能出现加载缓冲，影响体验。
            @Override
            public void onRewardVideoAdLoad(TTRewardVideoAd ad) {
                mttRewardVideoAd = ad;
                mttRewardVideoAd.setRewardAdInteractionListener(new TTRewardVideoAd.RewardAdInteractionListener() {

                    @Override
                    public void onAdShow() {
                    }

                    @Override
                    public void onAdVideoBarClick() {
                    }

                    @Override
                    public void onAdClose() {
                        loadAd("907439399", TTAdConstant.VERTICAL);
                    }

                    //视频播放完成回调
                    @Override
                    public void onVideoComplete() {

                    }

                    @Override
                    public void onVideoError() {
                    }

                    //视频播放完成后，奖励验证回调，rewardVerify：是否有效，rewardAmount：奖励梳理，rewardName：奖励名称
                    @Override
                    public void onRewardVerify(boolean rewardVerify, int rewardAmount, String rewardName) {
                    }

                });

            }
        });


    }

}
